@@ -28,7 +28,7 @@ def _add_brain_region(df, region_type):
     return df
 
 
-class CEMBASnmCAndSnm3C:
+class CEMBASnmCAndSnm3C(AutoPathMixIn):
     def __init__(self):
         # mapping metric
         self.CEMBA_SNMC_MAPPING_METRIC_PATH = CEMBA_SNMC_MAPPING_METRIC_PATH
@@ -52,9 +52,9 @@ class CEMBASnmCAndSnm3C:
         # dataset paths
         self.CEMBA_SNMC_MCDS_PATH = CEMBA_SNMC_MCDS_PATH
         self.CEMBA_SNM3C_MCDS_PATH = CEMBA_SNM3C_MCDS_PATH
-        self.CEMBA_SNM3C_3C_CHROM100K_RAW_ZARR = CEMBA_SNM3C_3C_CHROM100K_RAW_ZARR
-        self.CEMBA_SNM3C_3C_COMPARTMENT_ZARR = CEMBA_SNM3C_3C_COMPARTMENT_ZARR
-        self.CEMBA_SNM3C_3C_DOMAIN_INSULATION_ZARR = CEMBA_SNM3C_3C_DOMAIN_INSULATION_ZARR
+        self.CEMBA_SNM3C_3C_CHROM100K_RAW_ZARR_PATH = CEMBA_SNM3C_3C_CHROM100K_RAW_ZARR_PATH
+        self.CEMBA_SNM3C_3C_COMPARTMENT_ZARR_PATH = CEMBA_SNM3C_3C_COMPARTMENT_ZARR_PATH
+        self.CEMBA_SNM3C_3C_DOMAIN_INSULATION_ZARR_PATH = CEMBA_SNM3C_3C_DOMAIN_INSULATION_ZARR_PATH
 
         # other metadata
         self.CEMBA_LIU_2021_NATURE_SNMC_METADATA_PATH = CEMBA_LIU_2021_NATURE_SNMC_METADATA_PATH
@@ -68,6 +68,9 @@ class CEMBASnmCAndSnm3C:
         # internal variables
         self._mc_gene_mcds = None
         self._m3c_gene_mcds = None
+
+        # validate path or auto change prefix
+        self._check_file_path_attrs()
         return
 
     def _open_mc_gene_mcds(self):
@@ -286,7 +289,7 @@ class CEMBASnmCAndSnm3C:
         return gene_data
 
 
-class CEMBAATAC:
+class CEMBAATAC(AutoPathMixIn):
     """
     CEMBA ATAC-seq data
     """
@@ -300,6 +303,9 @@ class CEMBAATAC:
         self._full_name_map = pd.read_csv(self.CEMBA_ATAC_CLUSTER_FULL_NAME_PATH,
                                           index_col=0, sep='\t').squeeze()
         self._mapping_metric = None
+
+        # validate path or auto change prefix
+        self._check_file_path_attrs()
         return
 
     def get_atac_mapping_metric(self):
